summaryrefslogtreecommitdiff
path: root/pkg/build_bundle_with_venv.sh
diff options
context:
space:
mode:
Diffstat (limited to 'pkg/build_bundle_with_venv.sh')
-rwxr-xr-xpkg/build_bundle_with_venv.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/pkg/build_bundle_with_venv.sh b/pkg/build_bundle_with_venv.sh
index 15b495c5..65c52c6d 100755
--- a/pkg/build_bundle_with_venv.sh
+++ b/pkg/build_bundle_with_venv.sh
@@ -1,6 +1,6 @@
#!/bin/bash
###########################################################
# Build a Bitmask bundle inside a fresh virtualenv.
# To be run by Gitlab Runner,
# will produce an artifact for each build.
###########################################################
@@ -48,4 +48,4 @@ $VIRTUAL_ENV/bin/pip uninstall --yes pyzmq
$VIRTUAL_ENV/bin/pip install pyzmq --install-option="--zmq=bundled"
make bundle
-make bundle_apps
+make bundle_apps_linux
@@ -1,6 +1,6 @@
#!/bin/bash
###########################################################
-# Build a Bitmask bundle inside a fresh virtualenv.
+# Build a Bitmask bundle inside a fresh virtualenv (LINUX).
# To be run by Gitlab Runner,
# will produce an artifact for each build.